API
===

.. toctree::
   :maxdepth: 4

   dscript.commands
   dscript.models

dscript.alphabets
-----------------

.. automodule:: dscript.alphabets
   :members:
   :undoc-members:
   :show-inheritance:

dscript.fasta
-------------

.. automodule:: dscript.fasta
   :members:
   :undoc-members:
   :show-inheritance:

dscript.language\_model
-----------------------

.. automodule:: dscript.language_model
   :members:
   :undoc-members:
   :show-inheritance:

dscript.pretrained
------------------

.. automodule:: dscript.pretrained
    :members:
    :undoc-members:
    :show-inheritance:

dscript.utils
-------------

.. automodule:: dscript.utils
   :members:
   :undoc-members:
   :show-inheritance:
